xsdata.codegen.handlers.attribute\_implied module
=================================================

.. automodule:: xsdata.codegen.handlers.attribute_implied
   :members:
   :undoc-members:
   :show-inheritance:
